from setuptools import setup, find_packages


# Function to convert simple ETS project names and versions to a requirements
# spec that works for both development builds and stable builds.  Allows
# a caller to specify a max version, which is intended to work along with
# Enthought's standard versioning scheme -- see the following write up:
#    https://svn.enthought.com/enthought/wiki/EnthoughtVersionNumbers
def etsdep(p, min, max=None, literal=False):
    require = '%s >=%s.dev' % (p, min)
    if max is not None:
        if literal is False:
            require = '%s, <%sa' % (require, max)
        else:
            require = '%s, <%s' % (require, max)
    return require


# Declare our ETS project dependencies.
ETSCONFIG = etsdep('enthought.etsconfig', '2.0.2', '3.0')
DEBUG = etsdep('enthought.debug', '2.0.3', '3.0')
IO = etsdep('enthought.io', '2.0.3', '3.0')
LOGGER = etsdep('enthought.logger', '2.0.3', '3.0')
NAMING = etsdep('enthought.naming', '2.0.3', '3.0')
PLUGINSTEXTEDITOR = etsdep('enthought.plugins.text_editor', '2.0.4', '3.0')
PYFACE_DOCK = etsdep('enthought.pyface[dock]', '2.0.3', '3.0')
SWEETPICKLE = etsdep('enthought.sweet_pickle', '2.0.3', '3.0')
TRAITS_UI = etsdep('enthought.traits[ui]', '2.0.4', '3.0')
TRAITSUIWX = etsdep('enthought.traits.ui.wx', '2.0.4', '3.0')
TYPEMANAGER = etsdep('enthought.type_manager', '2.0.3', '3.0')
UTIL = etsdep('enthought.util', '2.0.3', '3.0')


setup(
    author = 'Enthought, Inc',
    author_email = 'info@enthought.com',
    dependency_links = [
        'http://code.enthought.com/enstaller/eggs/source',
        ],
    description = 'Envisage application framework',
    extras_require = {
        # All non-ets dependencies should be in this extra to ensure users can
        # decide whether to require them or not.
        'nonets': [
            "numpy >=1.0.2",
            "scipy >=0.5.2",
            ],
        },
    include_package_data = True,
    install_requires = [
        ETSCONFIG,
        DEBUG,
        IO,
        LOGGER,
        NAMING,
        PLUGINSTEXTEDITOR,
        PYFACE_DOCK,
        SWEETPICKLE,
        TRAITS_UI,
        TRAITSUIWX,
        TYPEMANAGER,
        UTIL,
        ],
    license = 'BSD',
    name = 'enthought.envisage',
    namespace_packages = [
        "enthought",
        ],
    packages = find_packages(exclude=['docs', 'examples', 'examples.*']),
    tests_require = [
        'nose >= 0.9',
        ],
    test_suite = 'nose.collector',
    url = 'http://code.enthought.com/envisage/',
    version = '2.0.4',
    zip_safe = False,
    )

